@@ -1,23 +1,44 @@
 import datetime
+import typing as t
 from decimal import Decimal
 
-
-DIRECTORS = [
-    {"id": 1, "name": "Peter Jackson"},
-    {"id": 2, "name": "George Lucas"},
-    {"id": 3, "name": "J.J. Abrams"},
-    {"id": 4, "name": "Gareth Edwards"},
-    {"id": 5, "name": "Irvin Kershner"},
-    {"id": 6, "name": "Richard Marquand"},
-    {"id": 7, "name": "Rian Johnson"},
-    {"id": 8, "name": "Ron Howard"},
+DIRECTORS: t.List[t.Dict[str, t.Any]] = [
+    {
+        "id": 1,
+        "name": "Peter Jackson",
+        "years_nominated": [2002, 2004],
+        "gender": "m",
+    },
+    {
+        "id": 2,
+        "name": "George Lucas",
+        "years_nominated": [1974, 1978],
+        "gender": "m",
+    },
+    {"id": 3, "name": "J.J. Abrams", "years_nominated": [], "gender": "m"},
+    {"id": 4, "name": "Gareth Edwards", "years_nominated": [], "gender": "m"},
+    {"id": 5, "name": "Irvin Kershner", "years_nominated": [], "gender": "m"},
+    {
+        "id": 6,
+        "name": "Richard Marquand",
+        "years_nominated": [],
+        "gender": "m",
+    },
+    {"id": 7, "name": "Rian Johnson", "years_nominated": [], "gender": "m"},
+    {
+        "id": 8,
+        "name": "Ron Howard",
+        "years_nominated": [2002, 2009],
+        "gender": "m",
+    },
 ]
 
-MOVIES = [
+
+MOVIES: t.List[t.Dict[str, t.Any]] = [
     {
         "name": "Star Wars: Episode IV - A New Hope",
         "rating": 93.3,
-        "duration": 125,
+        "duration": datetime.timedelta(minutes=125),
         "director": 2,
         "description": (
             "After Princess Leia, the leader of the Rebel Alliance, is held "
@@ -25,13 +46,16 @@ MOVIES = [
             "destroy the powerful weapon created by the Galactic Empire."
         ),
         "release_date": datetime.datetime(year=1977, month=12, day=27),
+        "oscar_nominations": 11,
         "won_oscar": True,
         "box_office": Decimal("775.5"),
+        "barcode": 3999361649,
+        "genre": 2,
     },
     {
         "name": "The Empire Strikes Back",
         "rating": 94.0,
-        "duration": 127,
+        "duration": datetime.timedelta(minutes=127),
         "director": 5,
         "description": (
             "Darth Vader is adamant about turning Luke Skywalker to the dark "
@@ -39,13 +63,16 @@ MOVIES = [
             "friends try to fend off the Imperial fleet."
         ),
         "release_date": datetime.datetime(year=1980, month=5, day=20),
+        "oscar_nominations": 4,
         "won_oscar": True,
         "box_office": Decimal("547.9"),
+        "barcode": 2384023507,
+        "genre": 2,
     },
     {
         "name": "Return of the Jedi",
         "rating": 82.0,
-        "duration": 136,
+        "duration": datetime.timedelta(minutes=136),
         "director": 6,
         "description": (
             "Luke Skywalker attempts to bring his father back to the light "
@@ -53,13 +80,16 @@ MOVIES = [
             "to destroy the second Death Star."
         ),
         "release_date": datetime.datetime(year=1983, month=6, day=2),
+        "oscar_nominations": 5,
         "won_oscar": True,
         "box_office": Decimal("475.3"),
+        "barcode": 9874111507,
+        "genre": 2,
     },
     {
         "name": "Star Wars: Episode I – The Phantom Menace",
         "rating": 53.0,
-        "duration": 136,
+        "duration": datetime.timedelta(minutes=136),
         "director": 2,
         "description": (
             "Two Jedi Knights set out to search for someone who can "
@@ -68,13 +98,16 @@ MOVIES = [
             "to the Force."
         ),
         "release_date": datetime.datetime(year=1999, month=7, day=16),
+        "oscar_nominations": 3,
         "won_oscar": False,
         "box_office": Decimal("1027.0"),
+        "barcode": 4637581510,
+        "genre": 2,
     },
     {
         "name": "Star Wars: Episode II – Attack of the Clones",
         "rating": 65,
-        "duration": 144,
+        "duration": datetime.timedelta(minutes=144),
         "director": 2,
         "description": (
             "While pursuing an assassin, Obi Wan uncovers a sinister plot to "
@@ -82,13 +115,16 @@ MOVIES = [
             "balance, the Jedi must defend the galaxy against the evil Sith."
         ),
         "release_date": datetime.datetime(year=2002, month=5, day=16),
+        "oscar_nominations": 1,
         "won_oscar": False,
         "box_office": Decimal("653.0"),
+        "barcode": 8392825607,
+        "genre": 2,
     },
     {
         "name": "Star Wars: Episode III – Revenge of the Sith",
         "rating": 80.0,
-        "duration": 140,
+        "duration": datetime.timedelta(minutes=140),
         "director": 2,
         "description": (
             "Anakin joins forces with Obi-Wan and sets Palpatine free from "
@@ -97,13 +133,16 @@ MOVIES = [
             "temptation."
         ),
         "release_date": datetime.datetime(year=2005, month=5, day=19),
+        "oscar_nominations": 1,
         "won_oscar": False,
         "box_office": Decimal("868.4"),
+        "barcode": 5174272602,
+        "genre": 2,
     },
     {
         "name": "Star Wars: The Force Awakens",
         "rating": 93.0,
-        "duration": 135,
+        "duration": datetime.timedelta(minutes=135),
         "director": 3,
         "description": (
             "A new order threatens to destroy the New Republic. Finn, Rey and "
@@ -111,13 +150,16 @@ MOVIES = [
             "to stop them and find Luke, the last surviving Jedi."
         ),
         "release_date": datetime.datetime(year=2015, month=12, day=17),
+        "oscar_nominations": 5,
         "won_oscar": False,
         "box_office": Decimal("2068.0"),
+        "barcode": 9476361634,
+        "genre": 2,
     },
     {
         "name": "Rogue One: A Star Wars Story",
         "rating": 83.1,
-        "duration": 133,
+        "duration": datetime.timedelta(minutes=133),
         "director": 4,
         "description": (
             "When she's a child, Jyn's father is forcibly taken by the Empire "
@@ -125,13 +167,16 @@ MOVIES = [
             "group of resistance fighters, who aim to steal its blueprints."
         ),
         "release_date": datetime.datetime(year=2016, month=12, day=13),
+        "oscar_nominations": 2,
         "won_oscar": False,
         "box_office": Decimal("1056.0"),
+        "barcode": 6396501778,
+        "genre": 2,
     },
     {
         "name": "Star Wars: The Last Jedi",
         "rating": 91.2,
-        "duration": 152,
+        "duration": datetime.timedelta(minutes=152),
         "director": 7,
         "description": (
             "Rey seeks to learn the ways of the Jedi under Luke Skywalker, "
@@ -139,13 +184,16 @@ MOVIES = [
             "against the First Order."
         ),
         "release_date": datetime.datetime(year=2017, month=12, day=14),
+        "oscar_nominations": 4,
         "won_oscar": False,
         "box_office": Decimal("1333.0"),
+        "barcode": 1020122875,
+        "genre": 2,
     },
     {
         "name": "Solo: A Star Wars Story",
         "rating": 70.5,
-        "duration": 135,
+        "duration": datetime.timedelta(minutes=135),
         "director": 8,
         "description": (
             "In a galaxy where hyperfuel is in high demand, Han Solo gets "
@@ -153,13 +201,16 @@ MOVIES = [
             "and meets individuals who change his life."
         ),
         "release_date": datetime.datetime(year=2018, month=5, day=25),
+        "oscar_nominations": 0,
         "won_oscar": False,
         "box_office": Decimal("393.2"),
+        "barcode": 4949091770,
+        "genre": 2,
     },
     {
         "name": "Star Wars: The Rise of Skywalker",
         "rating": 54.7,
-        "duration": 142,
+        "duration": datetime.timedelta(minutes=142),
         "director": 3,
         "description": (
             "The surviving Resistance faces the First Order once more as Rey, "
@@ -167,13 +218,16 @@ MOVIES = [
             "knowledge of generations behind them, the final battle commences."
         ),
         "release_date": datetime.datetime(year=2019, month=12, day=19),
+        "oscar_nominations": 3,
         "won_oscar": False,
         "box_office": Decimal("1074.0"),
+        "barcode": 3592641903,
+        "genre": 2,
     },
     {
         "name": "The Lord of the Rings: The Fellowship of the Ring",
         "rating": 91.1,
-        "duration": 208,
+        "duration": datetime.timedelta(minutes=208),
         "director": 1,
         "description": (
             "A young hobbit, Frodo, who has found the One Ring that belongs "
@@ -182,13 +236,16 @@ MOVIES = [
             "destroyed."
         ),
         "release_date": datetime.datetime(year=2001, month=12, day=10),
+        "oscar_nominations": 12,
         "won_oscar": True,
         "box_office": Decimal("887.8"),
+        "barcode": 9520764061,
+        "genre": 1,
     },
     {
         "name": "The Lord of the Rings: The Two Towers",
         "rating": 95.2,
-        "duration": 223,
+        "duration": datetime.timedelta(minutes=223),
         "director": 1,
         "description": (
             "Frodo and Sam arrive in Mordor with the help of Gollum. A number "
@@ -196,13 +253,16 @@ MOVIES = [
             "Saruman launches an assault on it."
         ),
         "release_date": datetime.datetime(year=2002, month=12, day=11),
+        "oscar_nominations": 6,
         "won_oscar": True,
         "box_office": Decimal("951.2"),
+        "barcode": 2545685641,
+        "genre": 1,
     },
     {
-        "name": "The Lord of the Rings - The Return of the King",
+        "name": "The Lord of the Rings: The Return of the King",
         "rating": 93.0,
-        "duration": 201,
+        "duration": datetime.timedelta(minutes=201),
         "director": 1,
         "description": (
             "The former Fellowship members prepare for the final battle. "
@@ -210,13 +270,16 @@ MOVIES = [
             "they follow Gollum unaware of the path he is leading them to."
         ),
         "release_date": datetime.datetime(year=2003, month=12, day=17),
+        "oscar_nominations": 12,
         "won_oscar": True,
         "box_office": Decimal("1142.0"),
+        "barcode": 6118332538,
+        "genre": 1,
     },
     {
         "name": "The Hobbit: An Unexpected Journey",
         "rating": 64.2,
-        "duration": 182,
+        "duration": datetime.timedelta(minutes=182),
         "director": 1,
         "description": (
             "Bilbo Baggins, a hobbit, is persuaded into accompanying a wizard "
@@ -224,13 +287,16 @@ MOVIES = [
             "Erebor and all its riches from the dragon Smaug."
         ),
         "release_date": datetime.datetime(year=2012, month=12, day=12),
+        "oscar_nominations": 3,
         "won_oscar": False,
         "box_office": Decimal("1021.0"),
+        "barcode": 3604722656,
+        "genre": 1,
     },
     {
         "name": "The Hobbit: The Desolation of Smaug",
         "rating": 74.9,
-        "duration": 187,
+        "duration": datetime.timedelta(minutes=187),
         "director": 1,
         "description": (
             "Bilbo Baggins, a hobbit, and his companions face great dangers "
@@ -239,13 +305,16 @@ MOVIES = [
             "dragon Smaug."
         ),
         "release_date": datetime.datetime(year=2013, month=12, day=13),
+        "oscar_nominations": 3,
         "won_oscar": False,
         "box_office": Decimal("958.0"),
+        "barcode": 2522965834,
+        "genre": 1,
     },
     {
         "name": "The Hobbit: The Battle of the Five Armies",
         "rating": 59.0,
-        "duration": 164,
+        "duration": datetime.timedelta(minutes=164),
         "director": 1,
         "description": (
             "Bilbo fights against a number of enemies to save the life of his "
@@ -253,7 +322,55 @@ MOVIES = [
             "arises."
         ),
         "release_date": datetime.datetime(year=2014, month=12, day=1),
+        "oscar_nominations": 1,
         "won_oscar": False,
         "box_office": Decimal("956.0"),
+        "barcode": 3939605744,
+        "genre": 2,
     },
 ]
+
+
+STUDIOS: t.List[t.Dict[str, t.Any]] = [
+    {
+        "name": "Shepperton Studios",
+        "facilities": {
+            "sound_stage": True,
+            "catering": True,
+            "water_tank": True,
+        },
+    }
+]
+
+
+# Some random words used to generate fake movie names.
+MOVIE_WORDS: t.List[str] = [
+    "Adventure",
+    "Alien",
+    "Armageddon",
+    "Android",
+    "Bridge",
+    "Captain",
+    "Destruction",
+    "Evolution",
+    "Extreme",
+    "Fantasy",
+    "Friend",
+    "Galaxy",
+    "King",
+    "Lord",
+    "Master",
+    "Max",
+    "Mutant",
+    "Outpost",
+    "Partner",
+    "Phantom",
+    "Power",
+    "Returns",
+    "Revenge",
+    "Robot",
+    "Star",
+    "Throne",
+    "Thunder",
+    "Twin",
+]
